Class: Dependabot::DotnetSdk::DotNetSdkPackageManager
- Inherits:
-
Ecosystem::VersionManager
- Object
- Ecosystem::VersionManager
- Dependabot::DotnetSdk::DotNetSdkPackageManager
- Extended by:
- T::Sig
- Defined in:
- lib/dependabot/dotnet_sdk/package_manager.rb
Constant Summary collapse
- NAME =
"dotnet_sdk"- VERSION =
we are not using any native helper or 3rd party utility for package manager, So we supply a placeholder version with for our package manager
"1.0.0"- SUPPORTED_VERSIONS =
T.let([].freeze, T::Array[Dependabot::Version])
- DEPRECATED_VERSIONS =
T.let([].freeze, T::Array[Dependabot::Version])
Instance Method Summary collapse
- #deprecated? ⇒ Boolean
-
#initialize ⇒ DotNetSdkPackageManager
constructor
A new instance of DotNetSdkPackageManager.
- #unsupported? ⇒ Boolean
Constructor Details
#initialize ⇒ DotNetSdkPackageManager
Returns a new instance of DotNetSdkPackageManager.
33 34 35 36 37 38 39 40 |
# File 'lib/dependabot/dotnet_sdk/package_manager.rb', line 33 def initialize super( name: NAME, version: Version.new(VERSION), deprecated_versions: DEPRECATED_VERSIONS, supported_versions: SUPPORTED_VERSIONS ) end |
Instance Method Details
#deprecated? ⇒ Boolean
43 44 45 |
# File 'lib/dependabot/dotnet_sdk/package_manager.rb', line 43 def deprecated? false end |
#unsupported? ⇒ Boolean
48 49 50 |
# File 'lib/dependabot/dotnet_sdk/package_manager.rb', line 48 def unsupported? false end |